==> react-datagrid-3.0.1-beta3.tgz: package/index.js <==
import React from 'react'
import { render } from 'react-dom'
import Component from 'react-class'

import { Flex } from 'react-flex'
import DataGrid, { ColumnGroup } from './src'
import './index.scss'

import gen from './generate'

const data = new Promise((rez, rej) => {
  setTimeout(() => {
    rez(gen(10000))
    // rez('hello world')
  }, 1000)
})


const columns = [
  {
    name: 'firstName',
    textAlign: 'center'
  }, {
    name: 'lastName', 
    width: 150,
    textAlign: 'center'
  }, {
    name: 'email',
    textAlign: 'right'
  }, {
    name: 'city',
    flex: 3,
    textAlign: 'right'
  }
]

const columns2 = [
  {
    name: 'firstName',
    textAlign: 'center'
  }, {
    name: 'lastName'
  }, {
    name: 'email',
    width: 400
  }, {
    name: 'email',
    width: 400
  }, {
    name: 'email',
    width: 400
  }, 
  {
    render: function(...arg){
      console.log(...arg)    
      return <div> hey </div>
    }
  }
]

class App extends Component {
  constructor(props){
    super(props)

    this.state = {
      height: 500
    }
  }
  render(){
    return <Flex 
      column 
      alignItems="stretch" 
      className="app"
      style={{
        height: this.state.height
      }}
    >
      <h1>  
        React DataGrid by ZippyUi
      </h1>

      <div>
        <button 
          style={{
            marginBottom: 10
          }}
          onClick={() => this.setState({
            height: this.state.height + 10
          })}
        >
          Add Height
        </button>
      </div>

      <DataGrid
        className="grid"
        columns={columns}
        dataSource={data}
        idProperty="id"
        rowHeight={40}
      >
        <ColumnGroup fixed columns={columns} />
        <ColumnGroup className="myColumnGroup" columns={columns2} />
      </DataGrid>
    </Flex>
  }
}


render(<App />, document.getElementById('content'))

==> react-datagrid-3.0.2-beta3.tgz: package/index.js <==
import React from 'react'
import { render } from 'react-dom'
import Component from 'react-class'

import { Flex } from 'react-flex'
import DataGrid, { ColumnGroup, Column } from './src'
import './index.scss'

import gen from './generate'

import Perf from 'react-addons-perf'

global.Perf = Perf

const data = new Promise((rez, rej) => {
  setTimeout(() => {
    rez(gen(1000))
    // rez('hello world')
  }, 100)
})

const createData = (n = 20) => new Promise((rez, rej) => {
  setTimeout(() => {
    rez(gen(n))
    // rez('hello world')
  }, 1000)
})

const columns = [
  {
    name: 'firstName',
    textAlign: 'center',
    minWidth: 100,
    maxWidth: 150
  }, {
    name: 'lastName', 
    width: 50,
    textAlign: 'center'
  }, {
    name: 'email',
    textAlign: 'right'
  }, {
    name: 'city',
    flex: 3,
    textAlign: 'right'
  }
]

const columns2 = [
  {
    name: 'firstName',
    textAlign: 'center'
  }, {
    name: 'lastName'
  }, {
    name: 'email',
    width: 400
  }, {
    name: 'email',
    width: 400
  }, {
    name: 'email',
    width: 400
  }, {
    name: 'email',
    width: 400
  }
]

const columns3 = [
  {
    name: 'firstName',
    title: 'test',
    textAlign: 'center',
    width: 0,
  }
]

class App extends Component {
  constructor(props){
    super(props)

    this.state = {
      height: 500,
      data: createData(1000)
    }
  }

  changeData(){
    this.setState({
      data: null
    })
    
    setTimeout(() => {
      this.setState({
        data: createData(50)
      })
    }, 0)
  }

  render(){
    return <Flex 
      column 
      alignItems="stretch" 
      className="app"
      style={{
        height: this.state.height
      }}
    >
      <h1>  
        React DataGrid by ZippyUi
      </h1>

      <div>
        <button 
          style={{
            marginBottom: 10
          }}
          onClick={() => this.setState({
            height: this.state.height + 10
          })}
        >
          Add Height
        </button>
        <button onClick={() => this.changeData(5)}>Load other data</button>
      </div>

      <DataGrid
        className="grid"
        columns={columns}
        dataSource={this.state.data}
        idProperty="id"
        rowHeight={40}
        defaultSelected={{1:1, 2:2, 3:3}}
        onSelectionChange={selected => console.log(selected)}
        hideHeader
      >
        <ColumnGroup>
          <Column title="Text" name="firstName" minWidth={400} />
        </ColumnGroup>
        <ColumnGroup className="myColumnGroup" columns={columns2} />
        <ColumnGroup fixed={false} width={0} columns={columns3} style={{color: 'red'}} />
      </DataGrid>
    </Flex>
  }
}

        // <ColumnGroup fixed columns={columns} />

render(<App />, document.getElementById('content'))
